# session manager: zellij
# https://zellij.dev

def "sessions" [] {
  zellij list-sessions | columnar | reject column1 | rename name age bind }

def "session end" [] { zellij da }
def recess [] { session end; sessions; }

def "session choose" [] {
  ((ls ~/.config/zellij/session/ | get name) ++ (sessions | get name)) |
  each {|l| basename $l '.kdl' } |
  uniq | str join "\n" | fzf }

def "session running" []: nothing -> bool {
  $env | items {|k,s| $k} | any {|k| $k == ZELLIJ } }

def "session name" [name?:string]: nothing -> string {
  if ($name != null) { $name } else { basename $env.PWD | tr . _ } | str trim }

def "session has" [name?:string]: nothing -> bool {
  (session name $name) in (sessions) }

def "session run" [name?:string] {
  let name = if ($name == null) { session choose } else { $name }
  if (session has $name) { zellij attach $name } else { zellij -l $name -s $name } }

def "session record" [name?:string] {
  let name = if ($name == null) { session choose } else { $name }
  asciinema rec --command $"nu -e 'session hop ($name)'" $"($env.HOME)/rec/session.run.($name).(clock | str trim).rec" }

def "session hop" [name?:string] {
  let name = if ($name == null) { session choose } else { $name }
  if (sessions | where name == $name | is-empty
  ) { zellij --layout $name --session $name
  } else { zellij attach -c -- $name }
}

def "session access" [] { "~/rec/session.run.(.name).(.clock).rec" }
def hop [name?:string] { session hop $name }
